Re-enabled the EhCacheManager

git-svn-id: https://svn.apache.org/repos/asf/incubator/jsecurity/import/trunk@713755 13f79535-47bb-0310-9956-ffa450edef68
diff --git a/src/org/jsecurity/mgt/CachingSecurityManager.java b/src/org/jsecurity/mgt/CachingSecurityManager.java
index 25fe1b1..847fb16 100644
--- a/src/org/jsecurity/mgt/CachingSecurityManager.java
+++ b/src/org/jsecurity/mgt/CachingSecurityManager.java
@@ -22,7 +22,7 @@
 import org.apache.commons.logging.LogFactory;
 import org.jsecurity.cache.CacheManager;
 import org.jsecurity.cache.CacheManagerAware;
-import org.jsecurity.cache.HashtableCacheManager;
+import org.jsecurity.cache.ehcache.EhCacheManager;
 import org.jsecurity.util.Destroyable;
 import org.jsecurity.util.LifecycleUtils;
 
@@ -120,7 +120,7 @@
      * Creates a {@link CacheManager CacheManager} instance to be used by this <code>SecurityManager</code>
      * and potentially any of its children components.
      * <p/>
      * This default implementation attempts to create an {@link EhCacheManager EhCacheManager}, assuming that
      * ehcache is in the classpath.  If Ehcache is not in the classpath, no cache manager will be created and this
      * method does nothing.
      * <p/>
@@ -139,13 +139,9 @@
         }
 
         try {
-            manager = new HashtableCacheManager();
-            /**
-             * TODO: JSEC-24
              EhCacheManager ehCacheManager = new EhCacheManager();
              ehCacheManager.init();
              manager = ehCacheManager;
-             */
         } catch (NoClassDefFoundError e) {
             if (log.isDebugEnabled()) {
                 log.debug("Ehcache was not found in the classpath. A default EhCacheManager cannot be created.");
@@ -120,7 +120,7 @@
      * and potentially any of its children components.
      * <p/>
-     * This default implementation attempts to create an {@link EhCacheManager EhCacheManager}, assuming that
+     * This default implementation attempts to create an {@link org.jsecurity.cache.ehcache.EhCacheManager EhCacheManager}, assuming that
      * ehcache is in the classpath.  If Ehcache is not in the classpath, no cache manager will be created and this
      * method does nothing.